pub struct GainController2 {
pub input_volume_controller: bool,
pub adaptive_digital: Option<AdaptiveDigital>,
pub fixed_digital: FixedDigital,
}Expand description
Automatic Gain Controller 2 (AGC2) settings.
AGC2 brings the captured audio signal to the desired level by combining three controllers (input volume, adaptive digital, and fixed digital) and a limiter.
Fields
input_volume_controller: boolEnable the input volume controller. Adjusts the input volume applied when audio is captured (e.g., microphone volume on a soundcard).
adaptive_digital: Option<AdaptiveDigital>Adaptive digital controller settings. Set to Some(...) to enable.
Adjusts and applies a digital gain after echo cancellation and
noise suppression.
fixed_digital: FixedDigitalApplies a fixed digital gain after the adaptive digital controller and before the limiter.